@@ -3,8 +3,9 @@ from plone.app.theming.interfaces import IThemeSettings
 from plone.registry.interfaces import IRegistry
 from Products.Five.browser import BrowserView
 from zope.component import getUtility
-from plone.app.caching.operations.utils import formatDateTime
 
+import dateutil
+import wsgiref
 
 class CustomCSSView(BrowserView):
     """
@@ -12,16 +13,19 @@ class CustomCSSView(BrowserView):
     """
 
     def __call__(self):
-
         registry = getUtility(IRegistry)
         theme_settings = registry.forInterface(IThemeSettings, False)
         self.request.response.setHeader(
             'Content-Type',
             'text/css; charset=utf-8',
         )
+        dt = theme_settings.custom_css_timestamp
+        # If the datetime object is timezone-naive, it is assumed to be local time.
+        if dt.tzinfo is not None:
+            dt = dt.astimezone(dateutil.tz.tzlocal())
+        # Format a Python datetime object as an RFC1123 date.
         self.request.response.setHeader(
             'Last-Modified',
-            formatDateTime(theme_settings.custom_css_timestamp),
+            wsgiref.handlers.format_date_time(time.mktime(dt.timetuple())),
         )
-        custom_css = theme_settings.custom_css
-        return custom_css
+        return theme_settings.custom_css
